# Attribution

## Data Sources

### Radio Browser

The station database contains data derived from [Radio Browser](https://www.radio-browser.info/).

- **License**: Open Database License (ODbL) v1.0
- **Website**: https://www.radio-browser.info/
- **API**: https://api.radio-browser.info/

Radio Browser is a community-driven database of internet radio stations.

### Icecast Directory (Xiph.org)

Additional station data from [Icecast Directory](https://dir.xiph.org/).

- **License**: Open Source
- **Website**: https://dir.xiph.org/
- **Project**: https://icecast.org/
- **Description**: Xiph.org community-maintained directory of Icecast servers

## Stream Metadata

Song metadata (artist, title, play times) is collected directly from radio stream servers via:

- ICY metadata protocol
- Icecast status endpoints

This observational data is independently collected and owned by radiomcp.

---

## Other Credits

- **mpv** — Media player (https://mpv.io/)
- **VLC** — Media player (https://www.videolan.org/)
- **FFmpeg** — Multimedia framework (https://ffmpeg.org/)
- **wttr.in** — Weather data for recommendations (https://wttr.in/)

---

## How to Cite

If you use the station database in your project:

```
Station data from radiomcp, derived from Radio Browser (https://www.radio-browser.info/)
Licensed under ODbL 1.0
```